``baseplate.lib.thrift_pool``
=============================

.. automodule:: baseplate.lib.thrift_pool

Configuration Parsing
---------------------

.. autofunction:: thrift_pool_from_config

Classes
-------

.. autoclass:: ThriftConnectionPool()
   :members:
